import { useCallback } from 'react';

import { changeCodeForTokens } from '../changeCodeForTokens';
import { UseLoginParams } from '../types';

export const useTokenExchange = ({
	baseUrl,
	clientId,
	tokenEndpoint,
	redirectUri,
}: UseLoginParams) => {
	const exchange = useCallback(async (code: string) => {
		const { data: tokens } = await changeCodeForTokens({
			baseUrl,
			tokenEndpoint,
			clientId,
			redirectUri: redirectUri,
			code,
		});
		if (tokens) {
			return {
				authenticated: true,
				accessToken: tokens.access_token,
				refreshToken: tokens.refresh_token,
				idToken: tokens.id_token,
				accessExpiresIn: tokens.expires_in,
				refreshExpiresIn: tokens.refresh_expires_in,
				sessionState: tokens.session_state,
			};
		}
	}, []);

	return { exchange };
};
