import React from 'react';
import styled from '@emotion/native';
import { StyleProp, TextStyle } from 'react-native';

export type FieldMessageProps = {
	color?: 'primary' | 'secondary' | 'positive' | 'negative';
	message?: string;
	size?: 'sm' | 'md' | 'lg' | 'xl';
	style?: StyleProp<TextStyle>;
};

export const FieldMessage: React.FC<FieldMessageProps> = ({
	style,
	message,
	color,
	size,
}) => {
	if (!message) {
		return null;
	}
	return (
		<FieldMessageText color={color} size={size} style={[style]}>
			{message}
		</FieldMessageText>
	);
};

const FieldMessageText = styled.Text<{
	color: FieldMessageProps['color'];
	size: FieldMessageProps['size'];
}>(({ theme, color, size }) => {
	return {
		paddingTop: 3,
		paddingLeft: 2,
		paddingBottom: 2,
		fontFamily: theme.fontFamily,
		color: theme.palette[color!].dark,
		fontSize: theme.fontSize[size!] - 2,
	};
});
