import React, { ReactNode } from 'react';
import styled from '@emotion/native';
import { StyleProp, TextStyle } from 'react-native';

export type LabelProps = {
	children: ReactNode;
	disabled?: boolean;
	size?: 'sm' | 'md' | 'lg' | 'xl';
	style?: StyleProp<TextStyle>;
};

export const Label: React.FC<LabelProps> = ({
	children,
	style,
	size = 'sm',
	disabled,
}) => {
	return (
		<LabelText disabled={disabled} size={size} style={[style]}>
			{children}
		</LabelText>
	);
};

const LabelText = styled.Text<{
	disabled: LabelProps['disabled'];
	size: LabelProps['size'];
}>(({ theme, disabled, size }) => {
	return {
		color: theme.palette.text.main,
		fontFamily: theme.fontFamily,
		paddingLeft: 2,
		paddingBottom: 4,
		fontSize: theme.fontSize[size!],

		...(disabled && {
			color: theme.palette.disabled,
		}),
	};
});
