import React, { Children, FC, ReactNode } from 'react';
import { StyleProp, View, ViewStyle } from 'react-native';

export type StackProps = {
	children: ReactNode;
	direction?: ViewStyle['flexDirection'];
	style?: StyleProp<ViewStyle>;
} & Omit<ViewStyle, 'direction'>;

export const Stack: FC<StackProps> = ({
	children,
	direction = 'row',
	gap = 0,
	style,
	...props
}) => {
	const childrenArray = Children.toArray(children);
	return (
		<View style={[{ display: 'flex', flexDirection: direction, gap }, style, props]}>
			{childrenArray.map((child) => child)}
		</View>
	);
};
