import React, { FC } from 'react';
import styled from '@emotion/native';

export type TypographyProps = {
	children: any;
	size?: 'h1' | 'h2' | 'h3' | 'h4' | 'text' | 'small';
};

export const Typography: FC<TypographyProps> = ({ children, size = 'text' }) => {
	return <TypographyText size={size}>{children}</TypographyText>;
};

const TypographyText = styled.Text<{
	size: TypographyProps['size'];
}>(
	({ theme }) => {
		return {
			fontFamily: theme.fontFamily,
		};
	},
	({ size, theme }) => {
		switch (size) {
			case 'h1': {
				return {
					fontSize: theme.fontSize['xxxl'],
				};
			}
			case 'h2': {
				return {
					fontSize: theme.fontSize['xxl'],
				};
			}
			case 'h3': {
				return {
					fontSize: theme.fontSize['xl'],
				};
			}
			case 'h4': {
				return {
					fontSize: theme.fontSize['lg'],
				};
			}
			case 'text': {
				return {
					fontSize: theme.fontSize['md'],
				};
			}
			case 'small': {
				return {
					fontSize: theme.fontSize['sm'],
				};
			}
			default: {
				return {};
			}
		}
	},
);
