export function debounceBefore(func: (...args: any[]) => any, timeout = 300) {
	let timer: ReturnType<typeof setTimeout> | undefined;
	return (...args: any[]) => {
		if (!timer) {
			func.apply(this, args);
		}
		clearTimeout(timer);
		timer = setTimeout(() => {
			timer = undefined;
		}, timeout);
	};
}

export function debounceAfter(func: (...args: any[]) => any, timeout = 300) {
	let timer: ReturnType<typeof setTimeout> | undefined;
	return (...args: any[]) => {
		clearTimeout(timer);
		timer = setTimeout(() => {
			func.apply(this, args);
		}, timeout);
	};
}
