import { isJSON } from '@procyon/utils/isJSON';

import { UseLoginParams } from './types';

export type UseFetchTokensParams = Pick<
	UseLoginParams,
	'baseUrl' | 'tokenEndpoint' | 'clientId'
> & {
	code: string;
	redirectUri: string;
};

export const changeCodeForTokens = async ({
	baseUrl,
	tokenEndpoint,
	clientId,
	code,
	redirectUri,
}: UseFetchTokensParams) => {
	try {
		const response = await fetch(`${baseUrl}${tokenEndpoint}`, {
			method: 'post',
			headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
			body: new URLSearchParams({
				code,
				client_id: clientId,
				grant_type: 'authorization_code',
				redirect_uri: redirectUri,
			}),
		});
		const data = await response
			.text()
			.then((text: string) => (isJSON(text) ? JSON.parse(text) : text));
		if (!response.ok) throw response;
		return { data };
	} catch (error) {
		return { error };
	}
};
