import { isJSON } from '@procyon/utils/isJSON';

import { UseLoginParams } from './types';

export type UseReAuthFetchParams = Pick<
	UseLoginParams,
	'baseUrl' | 'tokenEndpoint' | 'clientId'
> & {
	refreshToken: string;
};

export const renewAccessToken = async ({
	baseUrl,
	clientId,
	tokenEndpoint,
	refreshToken,
}: UseReAuthFetchParams) => {
	const response = await fetch(`${baseUrl}${tokenEndpoint}`, {
		method: 'post',
		headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
		body: new URLSearchParams({
			client_id: clientId,
			grant_type: 'refresh_token',
			refresh_token: refreshToken,
		}),
	});
	const data = await response
		.text()
		.then((text: string) => (isJSON(text) ? JSON.parse(text) : text));
	if (!response.ok) throw response;
	return data;
};
