import React, { FC, ReactNode } from 'react';
import styled from '@emotion/native';
import { View } from 'react-native';

import { Stack } from '@procyon/components/Stack';
import { BanIcon } from '@procyon/icons/Ban';
import { CheckCheckIcon } from '@procyon/icons/CheckCheck';
import { InfoIcon } from '@procyon/icons/Info';
import { useTheme } from '@procyon/styles/Theme';

export type AlertProps = {
	Icon?: ReactNode;
	children?: ReactNode;
	color?: 'primary' | 'secondary' | 'positive' | 'negative';
	title?: string;
};

export const Alert: FC<AlertProps> = ({ color = 'secondary', title, Icon, children }) => {
	const { theme } = useTheme();
	return (
		<MessageContainer aria-label="message" color={color}>
			<Stack direction="row" gap={10} alignItems={title ? 'flex-start' : 'center'}>
				{Icon !== undefined ? (
					Icon
				) : color === 'positive' ? (
					<CheckCheckIcon strokeWidth={1} color={theme.palette.positive.dark} />
				) : color === 'negative' ? (
					<BanIcon strokeWidth={1} color={theme.palette.negative.dark} />
				) : (
					<InfoIcon strokeWidth={1} color={theme.palette[color!].dark} />
				)}
				<View>
					{title && <MessageTitle color={color}>{title}</MessageTitle>}
					<MessageText>{children}</MessageText>
				</View>
			</Stack>
		</MessageContainer>
	);
};

const MessageContainer = styled(View)<{
	color: AlertProps['color'];
}>(({ theme, color }) => {
	return {
		backgroundColor: theme.palette[color!].light,
		borderRadius: theme.rounded.small,
		padding: theme.spacing.lg,
		minWidth: 200,
	};
});

const MessageTitle = styled.Text<{
	color: AlertProps['color'];
}>(({ theme, color }) => {
	return {
		fontFamily: theme.fontFamily,
		fontSize: theme.fontSize.md,
		color: theme.palette[color!].dark,
		marginBottom: theme.spacing.md,
		fontWeight: 'bold',
	};
});

const MessageText = styled.Text(({ theme }) => {
	return {
		fontFamily: theme.fontFamily,
		fontSize: theme.fontSize.sm,
	};
});
