import React, { FC, ReactElement, useMemo } from 'react';
import { range } from 'ramda';
import { addDays, isSameDay, isSameWeek, setDate } from 'date-fns';

import { CalendarProps } from '@procyon/components/Calendar/index';
import { Grid } from '@procyon/components/Grid';

import { DateSlotProps } from './DateSlot';
import { getStartOf } from './utils';

export type DaysViewProps = {
	DateSlotView: FC<DateSlotProps>;
	borderCollapse?: boolean;
	layout?: CalendarProps['layout'];
	onClick?: (date: Date | undefined) => void;
	selectWeek?: boolean;
	selected?: Date;
	type?: CalendarProps['type'];
	value?: Date;
	weekOfMonth: number;
	workDate: Date;
};

export function CalendarWeek(props: DaysViewProps): ReactElement {
	const {
		layout,
		DateSlotView,
		onClick,
		workDate,
		weekOfMonth,
		borderCollapse,
		value,
		selected,
		type,
		selectWeek,
	} = props;

	const getStart = (): Date => {
		if (layout === 'day') return workDate;
		const startOf = layout === 'month' ? setDate(workDate, 1) : workDate;
		return getStartOf(startOf, weekOfMonth);
	};

	const renderDays = useMemo(() => {
		const startOf = getStart();
		const columns = layout === 'day' ? 1 : 7;
		return (
			<Grid cols={{ xs: columns }}>
				{range(0, columns).map((dayOfWeek) => {
					const date = addDays(startOf, dayOfWeek++);
					return (
						<DateSlotView
							key={date.getTime()}
							date={date}
							isToday={isSameDay(date, new Date())}
							workDate={workDate}
							onClick={onClick}
							layout={layout}
							weekOfMonth={weekOfMonth}
							type={type}
							{...(selectWeek
								? {
										isSelected: selected
											? isSameWeek(date, selected, { weekStartsOn: 1 })
											: false,
									}
								: {
										borderCollapse,
										isSelected: selected ? isSameDay(date, selected) : false,
									})}>
							{date.getDate()}
						</DateSlotView>
					);
				})}
			</Grid>
		);
	}, [
		workDate,
		DateSlotView,
		layout,
		borderCollapse,
		weekOfMonth,
		value,
		selected,
		type,
	]);

	return <>{renderDays}</>;
}
