import React, { FC, useMemo } from 'react';
import styled from '@emotion/native';
import { format } from 'date-fns';
import { StyleProp, TextStyle, ViewStyle } from 'react-native';

import { CalendarProps } from '@procyon/components/Calendar/index';
import { Stack } from '@procyon/components/Stack';
import { Typography } from '@procyon/components/Typography';
import { CalendarFoldIcon } from '@procyon/icons/CalendarFold';
import { CircleArrowLeftIcon } from '@procyon/icons/CircleArrowLeft';
import { CircleArrowRightIcon } from '@procyon/icons/CircleArrowRight';

import { getWeekRange } from './utils';

export type ControlsProps = {
	layout: CalendarProps['layout'];
	onNextClick: () => void;
	onPrevClick: () => void;
	onTodayClick: () => void;
	style?: {
		container?: StyleProp<ViewStyle>;
		period?: StyleProp<TextStyle>;
	};
	type: CalendarProps['type'];
	workDate: Date;
};

export const Controls: FC<ControlsProps> = ({
	layout,
	type,
	workDate,
	onNextClick,
	onPrevClick,
	onTodayClick,
	style,
}) => {
	const Period = useMemo(() => {
		switch (layout) {
			case 'month':
				if (type === 'months') {
					return format(workDate, 'yyyy');
				}
				return format(workDate, 'MM. yyyy');
			case 'week':
				return [
					format(getWeekRange(workDate)[0], 'dd.MM.'),
					' - ',
					format(getWeekRange(workDate)[1], 'dd.MM.yyyy'),
				];
			case 'day':
				return format(workDate, 'dd.MM.yyyy');
		}
	}, [workDate, layout, type]);

	return (
		<Stack
			direction="row"
			justifyContent="space-between"
			alignItems="center"
			style={[style?.container]}>
			<Typography size="h2">{Period}</Typography>
			<Stack direction="row" gap={12}>
				<CalendarControlsIcon onPress={onPrevClick}>
					<CircleArrowLeftIcon fontSize={24} strokeWidth={1} />
				</CalendarControlsIcon>
				<CalendarControlsIcon onPress={onTodayClick}>
					<CalendarFoldIcon fontSize={24} strokeWidth={1} />
				</CalendarControlsIcon>
				<CalendarControlsIcon onPress={onNextClick}>
					<CircleArrowRightIcon fontSize={24} strokeWidth={1} />
				</CalendarControlsIcon>
			</Stack>
		</Stack>
	);
};

const CalendarControlsIcon = styled.Pressable(() => {
	return {
		...({ cursor: 'pointer' } as any),
	};
});
