import React, { FC } from 'react';
import styled from '@emotion/native';
import { StyleProp, TextStyle, View, ViewStyle } from 'react-native';

import { CalendarProps } from '@procyon/components/Calendar/index';
import { Grid } from '@procyon/components/Grid';
import { useTranslate } from '@procyon/localization/tolgee';

export type WeekDaysProps = {
	layout: CalendarProps['layout'];
	longNames?: boolean;
	style?: {
		container?: StyleProp<ViewStyle>;
		day?: StyleProp<TextStyle>;
	};
	workDate: Date;
};

export const WeekDays: FC<WeekDaysProps> = ({ workDate, layout, longNames, style }) => {
	const { t } = useTranslate();

	const dayOfWeek =
		new Date(workDate).getDay() === 0 ? 6 : new Date(workDate).getDay() - 1;

	const FULL_DAYS = [
		t('calendar.weekdays.monday'),
		t('calendar.weekdays.tuesday'),
		t('calendar.weekdays.wednesday'),
		t('calendar.weekdays.thursday'),
		t('calendar.weekdays.friday'),
		t('calendar.weekdays.saturday'),
		t('calendar.weekdays.sunday'),
	];

	let daysInWeekNames = FULL_DAYS.map((day) => day.substring(0, 2));

	if (longNames) daysInWeekNames = FULL_DAYS;
	if (layout === 'day') daysInWeekNames = [FULL_DAYS[dayOfWeek]];

	return (
		<CalendarWeekDaysContainer style={style?.container}>
			<Grid cols={{ xs: 7 }}>
				{daysInWeekNames.map((day) => (
					<CalendarWeekDays key={day}>
						<CalendarWeekDay style={style?.day}>{day}</CalendarWeekDay>
					</CalendarWeekDays>
				))}
			</Grid>
		</CalendarWeekDaysContainer>
	);
};

const CalendarWeekDaysContainer = styled(View)(({ theme }) => {
	return {
		borderBottomWidth: 1,
		borderColor: theme.palette.primary.dark,
		padding: theme.spacing.sm,
		marginBottom: theme.spacing.sm,
	};
});

const CalendarWeekDays = styled(View)(() => {
	return {
		alignItems: 'center',
	};
});

const CalendarWeekDay = styled.Text(({ theme }) => {
	return {
		fontFamily: theme.fontFamily,
		fontSize: theme.fontSize.md,
		fontWeight: 'bold',
		color: theme.palette.primary.dark,
	};
});
