import React from 'react';
import styled from '@emotion/native';

import { RadioButtonProps } from '@procyon/components/RadioButton';
import { CircleIcon } from '@procyon/icons/Circle';
import { CircleCheckIcon } from '@procyon/icons/CircleCheck';
import { useTheme } from '@procyon/styles/Theme';

export type RadioItemProps = {
	children: string;
	disabled?: boolean;
	selected?: boolean;
	value: string;
} & Partial<Omit<RadioButtonProps, 'value'>>;

export const RadioItem: React.FC<RadioItemProps> = ({
	value,
	disabled,
	selected,
	size = 'md',
	children,
	onChange,
}) => {
	const { theme } = useTheme();
	return (
		<RadioItemOption
			aria-label="radio-item"
			disabled={disabled}
			onPress={(e) => onChange?.(e, value)}>
			{selected ? (
				<CircleCheckIcon
					strokeWidth={1}
					size={theme.iconSize[size!] + 4}
					color={
						disabled
							? theme.palette.disabled
							: selected
								? theme.palette.primary.dark
								: theme.palette.text.main
					}
					fill={selected && theme.palette.primary.light}
				/>
			) : (
				<CircleIcon
					strokeWidth={1}
					size={theme.iconSize[size!] + 4}
					color={disabled ? theme.palette.disabled : theme.palette.primary.main}
				/>
			)}
			<RadioItemName disabled={disabled} size={size}>
				{children}
			</RadioItemName>
		</RadioItemOption>
	);
};

const RadioItemOption = styled.Pressable(() => {
	return {
		display: 'flex',
		flexDirection: 'row',
		alignItems: 'center',
		gap: 8,
	};
});

const RadioItemName = styled.Text<{
	disabled: RadioItemProps['disabled'];
	size: RadioItemProps['size'];
}>(({ theme, disabled, size }) => {
	return {
		fontFamily: theme.fontFamily,
		fontSize: theme.fontSize[size!],

		...(disabled && {
			color: theme.palette.disabled,
		}),
	};
});
