import React, { FC, ReactNode, useEffect } from 'react';
import { StyleProp, View, ViewStyle } from 'react-native';
import Animated, {
	useAnimatedStyle,
	useSharedValue,
	withRepeat,
	withSequence,
	withTiming,
} from 'react-native-reanimated';

import { useTheme } from '@procyon/styles/Theme';

export type PlaceholderProps = {
	active: boolean;
	children: ReactNode;
	layout: ({ key: number | string } & StyleProp<ViewStyle>)[];
	style?: {
		container?: StyleProp<ViewStyle>;
	};
};

export const Skeleton: FC<PlaceholderProps> = ({ active, children, layout, style }) => {
	const { theme } = useTheme();

	const opacity = useSharedValue(1);

	const animatedStyle = useAnimatedStyle(() => {
		return {
			opacity: opacity.value,
		};
	}, [opacity]);

	useEffect(() => {
		opacity.value = withRepeat(
			withSequence(
				withTiming(0.4, {
					duration: 2000,
				}),
				withTiming(1, {
					duration: 2000,
				}),
			),
			Infinity,
			true,
		);
	}, []);

	if (!active) {
		return children;
	}

	return (
		<View style={[{ width: '100%' }, style?.container]}>
			{layout.map(({ key, ...style }: any) => (
				<Animated.View
					key={key}
					style={[
						{
							backgroundColor: theme.palette.secondary.light,
							borderRadius: theme.spacing.md,
							...style,
						},
						animatedStyle,
					]}
				/>
			))}
		</View>
	);
};
