import React, { Children, FC, ReactNode } from 'react';
import { PressableProps } from 'react-native';

import { Grid, GridProps } from '@procyon/components/Grid';
import { useTable } from '@procyon/components/Table';
import { useHover } from '@procyon/hooks/useHover';
import { useTheme } from '@procyon/styles/Theme';

export type TableRowProps = {
	children: ReactNode | ReactNode[];
	head?: true;
	last?: boolean;
	row?: true;
	style?: GridProps['style'];
} & Omit<PressableProps, 'style'>;

export const TableRow: FC<TableRowProps> = ({
	children,
	head,
	row,
	last,
	style,
	...props
}) => {
	const { theme } = useTheme();
	const { cols, layout, hoverable } = useTable();

	const { hovered, onHoverIn, onHoverOut } = useHover();

	const defaultLayout = { sm: new Array(Children.count(children)).fill(1) };
	const defaultCols = { sm: Children.count(children) };

	return (
		<Grid
			cols={cols ?? defaultCols}
			layout={layout ?? defaultLayout}
			{...(hoverable && {
				onHoverIn,
				onHoverOut,
			})}
			{...props}
			style={{
				...(head && {
					row: [
						{
							backgroundColor: theme.palette.secondary.dark,
							borderTopLeftRadius: theme.rounded.small,
							borderTopRightRadius: theme.rounded.small,
						},
						style?.row,
					],
				}),
				...(row && {
					row: [
						{
							borderWidth: 1,
							borderTopWidth: 0,
							borderColor: theme.palette.secondary.main,
							...(hovered && {
								backgroundColor: theme.palette.secondary.light,
							}),
							...(last && {
								borderBottomWidth: 1,
								borderBottomLeftRadius: theme.rounded.small,
								borderBottomRightRadius: theme.rounded.small,
							}),
						},
						style?.row,
					],
				}),
				cell: [{ justifyContent: 'center' }, style?.cell],
			}}>
			{children}
		</Grid>
	);
};
