import React, { FC } from 'react';
import styled from '@emotion/native';
import { View } from 'react-native';

import { notNil } from '@procyon/utils/nil';

import { Alert } from '../Alert';
import { useToaster } from './context';

export type ToastersProps = {
	position:
		| 'bottomCenter'
		| 'bottomLeft'
		| 'bottomRight'
		| 'leftCenter'
		| 'rightCenter'
		| 'topCenter'
		| 'topLeft'
		| 'topRight';
};

export const Toasters: FC<ToastersProps> = ({ position }) => {
	const { toasters } = useToaster();

	if (!notNil(toasters)) {
		return null;
	}

	return (
		<ToastersContainer position={position}>
			{Object.keys(toasters).map((toasterId) => {
				const toaster = toasters[toasterId];
				return (
					<Alert key={toasterId} color={toaster.color} title={toaster.title}>
						{toaster.message}
					</Alert>
				);
			})}
		</ToastersContainer>
	);
};

const ToastersContainer = styled(View)<{
	position: ToastersProps['position'];
}>(
	() => {
		return {
			position: 'absolute',
		};
	},
	({ position }) => {
		switch (position) {
			case 'topLeft':
				return {
					top: 5,
					left: 5,
				};
			case 'topCenter':
				return {
					top: 5,
					left: '50%',
					transform: [
						{
							translateX: '-50%',
							translateY: '0',
						} as any,
					],
				};
			case 'topRight':
				return {
					top: 5,
					right: 5,
				};
			case 'bottomLeft':
				return {
					bottom: 5,
					left: 5,
				};
			case 'bottomCenter':
				return {
					bottom: 5,
					left: '50%',
					transform: [
						{
							translateX: '-50%',
							translateY: '0',
						} as any,
					],
				};
			case 'bottomRight':
				return {
					bottom: 5,
					right: 5,
				};
			case 'rightCenter': {
				return {
					top: '50%',
					transform: [
						{
							translateY: '-50%',
							translateX: '0',
						} as any,
					],
					right: 5,
				};
			}
			case 'leftCenter': {
				return {
					top: '50%',
					transform: [
						{
							translateY: '-50%',
							translateX: '0',
						} as any,
					],
					left: 5,
				};
			}
			default: {
				return {};
			}
		}
	},
);
