import React from 'react';
import { useController, useFormContext } from 'react-hook-form';

import { Checkbox } from '@procyon/components/Checkbox';
import { DatePicker } from '@procyon/components/DatePicker';
import { ListData } from '@procyon/components/List';
import { RadioButton } from '@procyon/components/RadioButton';
import { Selectbox } from '@procyon/components/Selectbox';
import { TextField } from '@procyon/components/TextField';
import { TimePicker } from '@procyon/components/TimePicker';
import { FieldTypes } from '@procyon/forms/types';

export type FieldProps<E extends ListData[]> = {
	name: string;
} & FieldTypes<E>;

export const Field = <E extends ListData[]>({ ...props }: FieldProps<E>) => {
	const { control } = useFormContext();

	const { field, fieldState } = useController({ name: props.name, control });

	switch (props.component) {
		case 'TEXT':
			return (
				<TextField
					{...props}
					value={field.value}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					onChange={(e, value) => field.onChange(value)}
					onBlur={field.onBlur}
				/>
			);
		case 'CHECK':
			return (
				<Checkbox
					{...props}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					checked={field.value}
					onChange={(e, checked) => field.onChange(checked)}
				/>
			);
		case 'RADIO':
			return (
				<RadioButton
					{...props}
					value={field.value}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					onChange={(e, value) => field.onChange(value)}>
					{props.children}
				</RadioButton>
			);
		case 'SELECT':
			return (
				<Selectbox
					{...props}
					value={field.value}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					onChange={(e, value) => field.onChange(value)}
				/>
			);
		case 'DATE':
			return (
				<DatePicker
					{...props}
					value={field.value}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					onChange={(e, value) => field.onChange(value)}
				/>
			);
		case 'TIME':
			return (
				<TimePicker
					{...props}
					value={field.value}
					{...(fieldState.error && {
						message: fieldState.error.message,
						color: 'negative',
					})}
					onChange={(e, value) => field.onChange(value)}
				/>
			);
		default:
			return null;
	}
};
