import React from 'react';
import {
	FieldValues,
	FormProvider,
	SubmitErrorHandler,
	SubmitHandler,
	UseFormHandleSubmit,
	UseFormReturn,
} from 'react-hook-form';
import { Platform } from 'react-native';
import invariant from 'tiny-invariant';

import { Nullable } from '@procyon/types';

type N<FD> = Nullable<Partial<FD>>;

export type FormProps<FD extends FieldValues> = {
	children: React.ReactNode;
	methods: Omit<UseFormReturn<N<FD>>, 'handleSubmit'> & {
		handleSubmit: UseFormHandleSubmit<FD, any>;
	};
	onFail?: SubmitErrorHandler<FD>;
	onSubmit?: SubmitHandler<FD>;
};

export function Form<FD extends FieldValues>(props: Readonly<FormProps<FD>>) {
	const { onSubmit, onFail, methods } = props;
	if (!onSubmit && Platform.OS === 'web') {
		invariant('Prop `onSubmit` should be a function when run on the web platform');
	}
	return (
		<FormProvider {...methods}>
			{Platform.OS === 'web' ? (
				<form onSubmit={methods.handleSubmit(onSubmit!, onFail)}>{props.children}</form>
			) : (
				props.children
			)}
		</FormProvider>
	);
}
