import React, { createContext, ReactNode, useContext, useEffect, useState } from 'react';
import { Theme } from '@emotion/react';
import { Dimensions } from 'react-native';

import { useTheme } from '@procyon/styles/Theme';

type ContextProps = {
	mq: keyof Theme['breakpoints'];
	setMq: React.Dispatch<React.SetStateAction<keyof Theme['breakpoints']>>;
};

const MediaQueryContext = createContext<ContextProps>({
	mq: 'xl',
	setMq: () => {},
});

export type MediaQueryProviderProps = {
	children: ReactNode;
};

export const MediaQueryProvider: React.FC<MediaQueryProviderProps> = ({ children }) => {
	const [mq, setMq] = useState<keyof Theme['breakpoints']>('xl');

	const { theme } = useTheme();
	const brs = theme.breakpoints;
	const brKeys = Object.keys(brs);

	const handleChange = () => {
		Object.entries(brs).some(([key, value], index) => {
			const next = brKeys[index + 1];
			const nextBr = brs[next];
			if (isInRange(value, nextBr)) {
				setMq(key as keyof Theme['breakpoints']);
				return true;
			}
		});
	};

	useEffect(() => {
		handleChange();
		const sub = Dimensions.addEventListener('change', handleChange);
		return () => {
			sub.remove();
		};
	}, []);

	return (
		<MediaQueryContext.Provider value={{ mq, setMq }}>
			{children}
		</MediaQueryContext.Provider>
	);
};

export const useMediaQuery = () => {
	const context = useContext(MediaQueryContext);
	if (!context) {
		throw new Error('useMediaQuery must be used within a MediaQueryProvider');
	}
	return context.mq;
};

const isInRange = (br: number, nextBr: number) => {
	const windowWidth = Dimensions.get('window').width;
	return br <= windowWidth && (nextBr >= windowWidth || br === nextBr);
};
