import React, { useState } from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { List } from '@procyon/components/List';
import { ListItem, ListItemText, ListItemView } from '@procyon/components/ListItem';
import { FlagIcon } from '@procyon/icons/Flag';

type Story = StoryObj<typeof List>;

export default {
	component: List,
	parameters: {
		docs: {
			description: {
				component: "`import { List } from '@procyon/components/List';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {},
	render: function Component(args) {
		const [value, setValue] = useState<number | undefined>(undefined);

		const onValueChange = (e, item: number) => {
			args.onClick?.(e, item);
			setValue(item);
		};

		return (
			<List
				selected={value}
				onClick={onValueChange}
				data={[
					{
						id: 'aa',
						label: 'Tiger',
					},
					{
						id: 2,
						label: 'Dolphin',
					},
				]}
			/>
		);
	},
};

export const ViewOnly: Story = {
	args: {},
	render: function Component() {
		return (
			<List
				mode="view"
				data={[
					{
						id: 1,
						label: 'Tiger',
					},
					{
						id: 2,
						label: 'Dolphin',
					},
				]}
			/>
		);
	},
};

export const Custom: Story = {
	args: {},
	render: function Component(args) {
		const [value, setValue] = useState<number | undefined>(undefined);

		const onValueChange = (e, item: number) => {
			args.onClick?.(e, item);
			setValue(item);
		};

		return (
			<List
				selected={value}
				onClick={onValueChange}
				data={[
					{
						id: 1,
						label: 'Flag',
						negative: true,
					},
					{
						id: 2,
						label: 'Dolphin',
					},
				]}
				Item={({ children, item, ...props }) => {
					if (item.negative) {
						return (
							<ListItem {...props} item={item} color="negative">
								<ListItemView>
									<FlagIcon color="red" strokeWidth={1} />
									<ListItemText style={[{ fontWeight: 'bold' }]}>{children}</ListItemText>
								</ListItemView>
							</ListItem>
						);
					} else {
						return (
							<ListItem {...props} item={item} color="positive">
								{children}
							</ListItem>
						);
					}
				}}
			/>
		);
	},
};
