import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { View } from 'react-native';

import { Button } from '@procyon/components/Button';
import { Toasters } from '@procyon/components/Toaster';
import {
	showToaster,
	ToasterProvider,
	useToaster,
} from '@procyon/components/Toaster/context';

type Story = StoryObj<typeof Toasters>;

export default {
	component: Toasters,
	argTypes: {
		position: {
			options: [
				'topLeft',
				'topCenter',
				'topRight',
				'rightCenter',
				'bottomLeft',
				'bottomCenter',
				'bottomRight',
				'leftCenter',
			],
			control: { type: 'radio' },
		},
	},
	decorators: [
		(Story) => (
			<View style={{ minHeight: 500 }}>
				<ToasterProvider>
					<Story />
				</ToasterProvider>
			</View>
		),
	],
} as Meta;

export const Hook: Story = {
	render: (args) => {
		const Comp = () => {
			const { showToaster } = useToaster();
			return (
				<Button
					{...args}
					onClick={() =>
						showToaster({
							id: 'toaster1',
							title: 'Text',
							message: 'Message',
						})
					}>
					Open Toaster message
				</Button>
			);
		};
		return (
			<>
				<Comp />
				<Toasters {...args} />
			</>
		);
	},
};

export const OutsideReact: Story = {
	name: 'Function',
	render: (args) => {
		return (
			<>
				<Button
					onClick={() =>
						showToaster({
							id: 'toaster2',
							title: 'Text',
							message: 'Message',
							color: 'positive',
						})
					}>
					Open Toaster message
				</Button>
				<Toasters {...args} />
			</>
		);
	},
};
