import React, { useEffect, useState } from 'react';
import { StoryObj } from '@storybook/react';

import { Checkbox } from '@procyon/components/Checkbox';

type Story = StoryObj<typeof Checkbox>;

export default {
	component: Checkbox,
	parameters: {
		docs: {
			description: {
				component: "`import Checkbox from '@procyon/components/Checkbox';`",
			},
		},
	},
	tags: ['autodocs'],
};

const Component = (args) => {
	const [checked, setChecked] = useState(args.checked);

	useEffect(() => {
		setChecked(args.checked);
	}, [args.checked]);

	const onValueChange = (e, checked: boolean) => {
		args.onClick?.(checked);
		setChecked(checked);
	};

	return <Checkbox {...args} checked={checked} onChange={onValueChange} />;
};

export const Primary: Story = {
	args: {
		label: 'Classic checkbox',
		checked: true,
	},
	render: (args) => <Component {...args} />,
};

export const Secondary: Story = {
	args: {
		label: 'Classic checkbox',
		description: 'Checkbox value',
		color: 'secondary',
		checked: true,
	},
	render: (args) => <Component {...args} />,
};

export const Positive: Story = {
	args: {
		label: 'Classic checkbox',
		description: 'Checkbox value',
		color: 'positive',
		checked: true,
	},
	render: (args) => <Component {...args} />,
};

export const Negative: Story = {
	args: {
		label: 'Classic checkbox',
		description: 'Checkbox value',
		color: 'negative',
		checked: true,
	},
	render: (args) => <Component {...args} />,
};

export const Disabled: Story = {
	args: {
		label: 'Classic checkbox',
		description: 'Checkbox value',
		disabled: true,
	},
	render: (args) => <Component {...args} />,
};

export const LabelOnLeftSide: Story = {
	args: {
		label: 'Classic checkbox',
		description: 'Checkbox value',
		labelPosition: 'left',
	},
	render: (args) => <Component {...args} />,
};

export const NoLabel: Story = {
	args: {
		description: 'Checkbox value',
	},
	render: (args) => <Component {...args} />,
};
