import React from 'react';
import type { Meta, StoryObj } from '@storybook/react';
import { View } from 'react-native';

import { Button } from '@procyon/components/Button';
import { Dropdown } from '@procyon/components/Dropdown';

type Story = StoryObj<typeof Dropdown>;

export default {
	component: Dropdown,
	parameters: {
		docs: {
			description: {
				component: "`import { Dropdown } from '@procyon/components/Dropdown';`",
			},
		},
	},
	decorators: [
		(Story) => (
			<View style={{ height: 200 }}>
				<Story />
			</View>
		),
	],
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {
		name: 'dropdown',
		MainButton: <Button>Main action</Button>,
		Buttons: ({ ...props }) => (
			<>
				<Button {...props}>Button A</Button>
				<Button {...props} color="negative">
					Button B
				</Button>
			</>
		),
	},
};

export const WithoutButtons: Story = {
	args: {
		name: 'dropdown-empty',
		MainButton: <Button>Main action</Button>,
	},
};

export const Small: Story = {
	args: {
		size: 'sm',
		name: 'dropdown-sm',
		MainButton: <Button size="sm">Main action</Button>,
		Buttons: ({ ...props }) => {
			return (
				<>
					<Button {...props}>Button A</Button>
					<Button {...props} color="negative">
						Button B, C and D
					</Button>
				</>
			);
		},
	},
};
