import React, { useState } from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { RadioButton } from '@procyon/components/RadioButton';
import { RadioItem } from '@procyon/components/RadioItem';

type Story = StoryObj<typeof RadioButton>;

export default {
	component: RadioButton,
	parameters: {
		docs: {
			description: {
				component: "`import { List } from '@procyon/components/List';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta;

function Component(args) {
	const [value, setValue] = useState<string | undefined>(args.value);

	const onValueChange = (e, value: string) => {
		args.onChange?.(e, value);
		setValue(value);
	};

	return (
		<RadioButton {...args} value={value} onChange={onValueChange}>
			{args.children}
		</RadioButton>
	);
}

export const Default: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		value: 'item1',
		children: (
			<>
				<RadioItem value={'item1'}>Item 1</RadioItem>
				<RadioItem value={'item2'}>Item 2</RadioItem>
			</>
		),
	},
	render: (args) => <Component {...args} />,
};

export const DefaultDisabled: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		disabled: true,
		children: (
			<>
				<RadioItem value={'item1'}>Item 1</RadioItem>
				<RadioItem value={'item2'}>Item 2</RadioItem>
			</>
		),
	},
	render: (args) => <Component {...args} />,
};

export const OptionDisabled: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		children: (
			<>
				<RadioItem disabled value={'item1'}>
					Item 1
				</RadioItem>
				<RadioItem value={'item2'}>Item 2</RadioItem>
			</>
		),
	},
	render: (args) => <Component {...args} />,
};

export const Horizontal: Story = {
	args: {
		name: 'default',
		label: 'Classic radio button',
		horizontal: true,
		children: (
			<>
				<RadioItem value={'item1'}>Item 1</RadioItem>
				<RadioItem value={'item2'}>Item 2</RadioItem>
			</>
		),
	},
	render: (args) => <Component {...args} />,
};
