import React, { useState } from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { View } from 'react-native';

import { ListItem } from '@procyon/components/ListItem';
import { ModalProvider } from '@procyon/components/Modal/context';
import { Modals } from '@procyon/components/Modal/Modals';
import { FieldText, Selectbox } from '@procyon/components/Selectbox';

type Story = StoryObj<typeof Selectbox>;

export default {
	component: Selectbox,
	parameters: {
		docs: {
			description: {
				component: `
\`import Selectbox from '@procyon/components/Selectbox';\`

You need to wrap this component with \`ModalProvider\` component.
`,
			},
		},
	},
	tags: ['autodocs'],
	decorators: [
		(Story) => (
			<ModalProvider>
				<View style={[{ height: 400 }]}>
					<Story />
					<Modals />
				</View>
			</ModalProvider>
		),
	],
} as Meta;

export const Default: Story = {
	args: {},
	render: function Component(args) {
		const [value, setValue] = useState<string | undefined>(undefined);

		const onValueChange = (e: any, item: string) => {
			args.onChange?.(e, item);
			setValue(item);
		};

		return (
			<Selectbox
				data={[
					{ id: 'item1', label: 'Today' },
					{ id: 'item2', label: 'Next available date' },
				]}
				name={'name1'}
				label={'I am Selectbox'}
				value={value}
				onChange={onValueChange}
				Input={({ data, value }) => {
					return <FieldText>{data.find(({ id }) => id === value)?.label}</FieldText>;
				}}
				Item={({ item, children, ...props }) => {
					return (
						<ListItem
							{...props}
							item={item}
							color={item.id === 'item2' ? 'negative' : 'primary'}>
							{children}
						</ListItem>
					);
				}}
			/>
		);
	},
};
