import React, { useState } from 'react';
import { Meta, StoryObj } from '@storybook/react';

import { TextField } from '@procyon/components/TextField';
import { CalendarFoldIcon } from '@procyon/icons/CalendarFold';
import { IMask } from '@procyon/utils/imask';

type Story = StoryObj<typeof TextField>;

export default {
	component: TextField,
	parameters: {
		docs: {
			description: {
				component: "`import TextField from '@procyon/components/TextField';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta<typeof TextField>;

function Component(args) {
	const [value, setValue] = useState<string | undefined>(args.value);

	const onValueChange = (e, value: string) => {
		args.onChange?.(e, value);
		setValue(value);
	};

	return <TextField {...args} value={value} onChange={onValueChange} />;
}

export const Primary: Story = {
	args: {
		name: 'field',
		label: 'i am label',
	},
	render: (args) => <Component {...args} />,
};

export const Secondary: Story = {
	args: {
		name: 'field',
		label: 'i am label',
		color: 'secondary',
	},
	render: (args) => <Component {...args} />,
};

export const Positive: Story = {
	args: {
		name: 'field',
		label: 'i am label',
		color: 'positive',
	},
	render: (args) => <Component {...args} />,
};

export const Negative: Story = {
	args: {
		name: 'field',
		label: 'i am label',
		color: 'negative',
	},
	render: (args) => <Component {...args} />,
};

export const Disabled: Story = {
	args: {
		name: 'field',
		value: 'Value',
		disabled: true,
	},
	render: (args) => <Component {...args} />,
};

export const NoLabel: Story = {
	args: {
		name: 'field',
		value: 'Value',
	},
	render: (args) => <Component {...args} />,
};

export const WithMask: Story = {
	args: {
		name: 'withMask',
		label: 'With mask',
		mask: IMask.createMask({
			mask: '000 00 - 00',
		}),
		value: '11111111',
	},
	render: (args) => <Component {...args} />,
};

export const WithMessage: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		value: ':-)',
		message: 'Field message.',
	},
	render: (args) => <Component {...args} />,
};

export const Multiline: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		value: 'a\nv\nd',
		multiline: true,
	},
	render: (args) => <Component {...args} />,
};

export const LeftIcon: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		LeftIcon: (props) => <CalendarFoldIcon {...props} />,
	},
	render: (args) => <Component {...args} />,
};

export const RightIcon: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		RightIcon: (props) => <CalendarFoldIcon {...props} />,
	},
	render: (args) => <Component {...args} />,
};

export const BothSideIcon: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		LeftIcon: (props) => <CalendarFoldIcon {...props} />,
		RightIcon: (props) => <CalendarFoldIcon {...props} />,
	},
	render: (args) => <Component {...args} />,
};

export const LeftText: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		leftText: 'http://',
	},
	render: (args) => <Component {...args} />,
};

export const RightText: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		rightText: '.com',
	},
	render: (args) => <Component {...args} />,
};

export const BothSideText: Story = {
	args: {
		name: 'field',
		label: 'TextField',
		leftText: 'http://',
		rightText: '.com',
	},
	render: (args) => <Component {...args} />,
};

export const Loader: Story = {
	args: {
		name: 'field',
		label: 'Loader',
		loading: true,
	},
	render: (args) => <Component {...args} />,
};
