import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { setHours } from 'date-fns';

import { Modals } from '@procyon/components/Modal';
import { ModalProvider } from '@procyon/components/Modal/context';
import { TimePicker } from '@procyon/components/TimePicker';

type Story = StoryObj<typeof TimePicker>;

const description = ` \`import TimePicker from '@procyon/components/TimePicker';\`

You need to wrap this component with \`ModalProvider\` component.
`;

export default {
	component: TimePicker,
	parameters: {
		docs: {
			description: {
				component: description,
			},
		},
	},
	tags: ['autodocs'],
	decorators: [
		(Story) => (
			<div style={{ height: '600px' }}>
				<ModalProvider>
					<Story />
					<Modals />
				</ModalProvider>
			</div>
		),
	],
} as Meta<typeof TimePicker>;

const date = new Date();

export const Default: Story = {
	args: {
		name: 'timePicker1',
		label: 'Choose time',
		value: setHours(date, 20),
	},
};

export const WithoutLabel: Story = {
	args: {
		name: 'timePicker2',
		value: setHours(date, 20),
	},
};

export const RestrictedTimes: Story = {
	args: {
		name: 'timePicker3',
		label: 'Choose time',
		value: setHours(date, 20),
		minute: {
			min: 0,
			max: 30,
		},
		hour: {
			min: 8,
			max: 17,
		},
		message: 'Choose time between 8:00 and 17:30',
	},
};
