import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { Text } from 'react-native';
import { Route } from 'wouter';

import { AppLayout } from '@procyon/components/AppLayout';
import { MenuItem } from '@procyon/components/MenuItem';
import { LayoutDashboardIcon } from '@procyon/icons/LayoutDashboard';
import { SettingsIcon } from '@procyon/icons/Settings';
import { UserIcon } from '@procyon/icons/User';

const Routes = () => (
	<>
		Hello.
		<Route path="/r1">
			<div>Conten 1</div>
		</Route>
		<Route path="/r2">
			<div>Conten 2</div>
		</Route>
	</>
);

type Story = StoryObj<typeof AppLayout>;

const TopNav = [
	(props) => (
		<MenuItem
			{...props}
			active
			href="/r1"
			Icon={(props) => <LayoutDashboardIcon {...props} />}>
			Dashboard
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="/r2">
			Uživatelé
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="/r3">
			Skupiny
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="https://procyon.romanjaros.dev" external>
			External
		</MenuItem>
	),
];

const SideNav = [
	(props) => (
		<MenuItem
			{...props}
			active
			href="/r1"
			Icon={(props) => <LayoutDashboardIcon {...props} />}>
			Dashboard
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="/r2">
			Uživatelé
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="/r3">
			Skupiny
		</MenuItem>
	),
	(props) => (
		<MenuItem {...props} href="https://procyon.romanjaros.dev" external>
			External
		</MenuItem>
	),
];

const UserNav = [
	(props) => (
		<MenuItem {...props} href="/r1" Icon={(props) => <SettingsIcon {...props} />} />
	),
	(props) => (
		<MenuItem {...props} href="/r1" Icon={(props) => <UserIcon {...props} />}>
			Procyon
		</MenuItem>
	),
];

export default {
	component: AppLayout,
	parameters: {
		layout: 'fullscreen',
		docs: {
			description: {
				component: "`import { AppLayout } from '@procyon/components/AppLayout';`",
			},
		},
	},
	tags: ['autodocs'],
} as Meta;

export const Default: Story = {
	args: {
		children: <Routes />,
		Logo: <Text>Procyon</Text>,
		TopNav,
		SideNav,
		UserNav,
	},
};

export const TopPanel: Story = {
	args: {
		Logo: <Text>Procyon</Text>,
		children: <Routes />,
		TopNav,
		UserNav,
	},
};

export const SidePanel: Story = {
	args: {
		children: <Routes />,
		Logo: <Text>Procyon</Text>,
		SideNav,
	},
};

export const NoLogo: Story = {
	args: {
		children: <Routes />,
		TopNav,
		UserNav,
	},
};

export const JustContent: Story = {
	args: {
		children: <>Hello</>,
	},
};
