import React, { FC, ReactNode } from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { Text, View } from 'react-native';

import { Grid } from '@procyon/components/Grid';

type Story = StoryObj<typeof Grid>;

const ColoredDiv: FC<{ children: ReactNode | ReactNode[] }> = ({ children }) => {
	return (
		<View
			style={{ backgroundColor: '#FFDFBA', margin: 1, padding: 5, alignItems: 'center' }}>
			<Text>{children}</Text>
		</View>
	);
};

export default {
	component: Grid,
	tags: ['autodocs'],
	args: {
		children: <ColoredDiv>&nbsp;</ColoredDiv>,
	},
} as Meta<typeof Grid>;

export const Default: Story = {
	render: () => (
		<Grid
			cols={{ sm: 10, md: 12 }}
			layout={{
				sm: [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 3, 3],
				md: [1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 5, 5],
			}}>
			<ColoredDiv>1</ColoredDiv>
			<ColoredDiv>2</ColoredDiv>
			<ColoredDiv>3</ColoredDiv>
			<ColoredDiv>4</ColoredDiv>
			<ColoredDiv>5</ColoredDiv>
			<ColoredDiv>6</ColoredDiv>
			<ColoredDiv>7</ColoredDiv>
			<ColoredDiv>8</ColoredDiv>
			<ColoredDiv>9</ColoredDiv>
			<ColoredDiv>10</ColoredDiv>
			<ColoredDiv>11</ColoredDiv>
			<ColoredDiv>12</ColoredDiv>
			<ColoredDiv>13</ColoredDiv>
			<ColoredDiv>14</ColoredDiv>
		</Grid>
	),
};
