import React from 'react';
import { Meta, StoryObj } from '@storybook/react';
import { Text, View } from 'react-native';

import { Button } from '@procyon/components/Button';
import { Modals } from '@procyon/components/Modal';
import {
	openModal as openOutsideReactModal,
	useModal,
} from '@procyon/components/Modal/context';
import { ModalContainer, ModalTitle } from '@procyon/components/Modal/Modals';

type Story = StoryObj<typeof Modals>;

export default {
	component: Modals,
	decorators: [
		(Story) => (
			<View style={{ height: 500 }}>
				<Story />
			</View>
		),
	],
} as Meta;

export const Hook: Story = {
	args: {},
	render: () => {
		const Comp = () => {
			const [openModal] = useModal('modal2', {
				Component: () => (
					<ModalContainer>
						<ModalTitle>Hello</ModalTitle>
						<Text>Hi there</Text>
					</ModalContainer>
				),
			});
			return <Button onClick={openModal}>Open Modal</Button>;
		};
		return <Comp />;
	},
};

export const OutsideComponent: Story = {
	name: 'Function',
	args: {},
	render: () => {
		return (
			<Button
				onClick={() =>
					openOutsideReactModal({
						Component: () => (
							<ModalContainer>
								<ModalTitle>Hello 2</ModalTitle>
								<Text>Hi there</Text>
							</ModalContainer>
						),
						id: 'modal3',
					})
				}>
				Open Modal
			</Button>
		);
	},
};
