import React, { FC, useMemo } from 'react';
import { times } from 'ramda';
import styled from '@emotion/native';
import { addMinutes, format } from 'date-fns';
import { Pressable, View } from 'react-native';

import { DateSlotProps } from '@procyon/components/Calendar/DateSlot';

export const WeekView: FC<DateSlotProps> = ({ date, onClick }) => {
	const handleClick = (index: number) => {
		if (onClick && date) {
			const dateTime = addMinutes(date.setHours(8, 0, 0, 0), 30 * index);
			onClick(dateTime);
		}
	};

	const agenda = useMemo(() => {
		return times((i) => {
			if (Math.round(Math.random())) {
				return (
					<Pressable key={i} onPress={() => handleClick(i)}>
						<CalendarHourSlot>event</CalendarHourSlot>
					</Pressable>
				);
			} else {
				return <CalendarHourSlot key={i}>-</CalendarHourSlot>;
			}
		}, 16);
	}, []);

	return (
		<View style={{ alignItems: 'stretch' }}>
			<CalendarDateText>{date ? format(date, 'dd') : null}</CalendarDateText>
			{agenda}
		</View>
	);
};

const CalendarHourSlot = styled.Text(({ theme }) => {
	return {
		padding: 4,
		height: 24,
		fontFamily: theme.fontFamily,
		backgroundColor: theme.palette.secondary.light,
	};
});

const CalendarDateText = styled.Text(({ theme }) => {
	return {
		padding: 4,
		marginBottom: 2,
		fontFamily: theme.fontFamily,
		fontSize: theme.fontSize.md,
		alignSelf: 'center',
		borderBottomWidth: 1,
		borderColor: theme.palette.primary.main,
	};
});
