import React from 'react';
import { View } from 'react-native';
import * as yup from 'yup';

import { Button } from '@procyon/components/Button';
import { Grid } from '@procyon/components/Grid';
import { Puzzle } from '@procyon/components/Puzzle';
import { RadioItem } from '@procyon/components/RadioItem';
import { Stack } from '@procyon/components/Stack';
import { Field } from '@procyon/forms/Field';
import { Form } from '@procyon/forms/Form';
import { useForm } from '@procyon/forms/useForm';

type FormData = {
	checkbox: boolean;
	datePicker: Date;
	radiobutton: string;
	selectBox: number;
	text: string;
	timePicker: Date;
};

const schema: yup.ObjectSchema<FormData> = yup.object({
	text: yup.string().required(),
	checkbox: yup.boolean().required(),
	radiobutton: yup.string().required(),
	selectBox: yup.number().required(),
	datePicker: yup.date().required(),
	timePicker: yup.date().required(),
});

export const ExampleForm = () => {
	const formMethods = useForm<FormData>({
		schema,
		defaultValues: {
			text: 'Hello from TextField',
			selectBox: 2,
			datePicker: new Date(),
			timePicker: new Date(),
			checkbox: true,
			radiobutton: 'item1',
		},
	});

	const onSubmit = (data: FormData) => {
		console.info(data);
	};

	return (
		<Form<FormData> onSubmit={onSubmit} methods={formMethods}>
			<Stack direction="column" gap={10}>
				<Grid cols={{ sm: 1, md: 2 }} gap={10}>
					<Field component="TEXT" name="text" label="Input" />
				</Grid>
				<Grid cols={{ sm: 2, md: 3, lg: 4 }} layout={{ lg: [1, 1, 2, 2, 2] }} gap={10}>
					<Field
						component="CHECK"
						name="checkbox"
						label="Checkbox"
						description="Do you Agree?"
					/>
					<Field component="RADIO" name="radiobutton" label="Radio Button" horizontal>
						<RadioItem value="item1">Item 1</RadioItem>
						<RadioItem value="item2">Item 2</RadioItem>
					</Field>
					<Field
						component="SELECT"
						name="selectBox"
						label="SelectBox"
						getLabel={({ name }) => name}
						data={[
							{ id: 1, name: 'Item 1' },
							{ id: 2, name: 'Item with no. 2' },
						]}
					/>
					<Field component="DATE" name="datePicker" label="DatePicker" />
					<Field component="TIME" name="timePicker" label="TimePicker" />
				</Grid>
				<Puzzle onVerified={() => null} />
				<Grid cols={{ sm: 2 }} gap={10}>
					<View />
					<Button fullWidth onClick={formMethods.handleSubmit(onSubmit)}>
						Send
					</Button>
				</Grid>
			</Stack>
		</Form>
	);
};
